package com.lyms.yimiao.web.controller.v1;

import com.lymsh.mommybaby.basecommon.base.BaseController;
import com.lymsh.mommybaby.basecommon.util.ResultUtils;
import com.lymsh.yimiao.main.data.enumdata.PositionEnum;
import com.lymsh.yimiao.main.data.model.MedVaccineName;
import com.lymsh.yimiao.main.data.model.MedVaccineNameQuery;
import com.lymsh.yimiao.main.data.service.MedVaccineNameService;
import com.lymsh.yimiao.main.data.util.JsonUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletResponse;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**     疫苗信息接口
 * Created by Administrator on 2016/4/29 0029.
 */
@Controller
@RequestMapping("/v1")
public class VaccineNamesController extends BaseController{

    @Autowired
    private MedVaccineNameService medVaccineNameService;

    private final static String isDelete = "1";

    private final static String MIAN_FEI = "免费";
    private final static String SHOU_FEI = "收费";
    private final static String YI_LEI_YI_MIAO = "一类疫苗";
    private final static String ER_LEI_YI_MIAO = "二类疫苗";

    /**
     *
     * @param response
     * @param id        疫苗名称ID
     */
    @RequestMapping(value = "/vaccineNames", method = RequestMethod.GET)
    public void getVaccineNames(HttpServletResponse response,
                                 @RequestParam("id") String id){
        MedVaccineName medVaccineName = medVaccineNameService.getMedVaccineName(id);
        if (medVaccineName==null || !"1".equals(medVaccineName.getIsDelete())){
            ResultUtils.buildParameterErrorResultAndWrite(response,"疫苗名称信息不存在");
            return;
        }
        Map<String,Object> map = new HashMap<>();
        map.put("id",medVaccineName.getVnId());
        //1.免费2.收费
        map.put("vaccineType",medVaccineName.getVnVaccineType());
        //疫苗名称
        map.put("title",medVaccineName.getVnName());
        //接种预防疾病
        map.put("preventDisease",medVaccineName.getVnPreventDisease());
        // 接种月龄 需要处理成  3月龄(1/2),6月龄(2/2)

        String mouthAge = null;

        if (medVaccineName.getVnMonthAge()!=null){
            String[] ages = medVaccineName.getVnMonthAge().split(",");//1,2
            List<String> list = new ArrayList();
            for (int j = 0; j < ages.length ; j++) {
                String q = ages[j]+"月龄"+"("+ (j+1) +"/"+ages.length+")";
                list.add(q);
            }
            StringBuffer q = new StringBuffer();
            for (String a : list){
                q = q.append(a).append(",");
            }
            q.deleteCharAt(q.length()-1);

            mouthAge = new String(q);
        }
        map.put("mouthAge",mouthAge);
        //接种部位
        map.put("position",medVaccineName.getVnPosition());
        //TODO 接种效果
        map.put("InoculateEffect",null);
        //接种禁忌
        map.put("taboo",medVaccineName.getVnTaboo());
        //不良反应
        map.put("description",medVaccineName.getVnDescription());

        writeJson(response, JsonUtil.obj2JsonString(map));
    }

    /**
     * 获取疫苗详情
     * @param response
     * @param ids
     * @return
     */
    @RequestMapping(value = "/getVaccineNames")
    public ModelAndView getVaccineName(HttpServletResponse response,
                                    @RequestParam(value = "ids") String ids) {
        ModelAndView mv = new ModelAndView("error");

        if (ids == null) {
            mv.addObject("msg", "vaccineNames id is null");
        }

        List<MedVaccineName> nameAllList = new ArrayList<>();

        String[] temp = ids.split(",");
        for (String id : temp){
            MedVaccineNameQuery query = new MedVaccineNameQuery();
            query.setIsDelete(isDelete);
            query.setVnId(id);
            List<MedVaccineName> nameList = medVaccineNameService.queryMedVaccineName(query);
            if (nameList.size()==0){
                mv.setViewName("empty");
                mv.addObject("msg", "无疫苗详情信息");
            }

            for (MedVaccineName data : nameList){

                String[] ages = data.getVnMonthAge().split(",");//1,2
                String monthAgeStr = "";
                for (int j = 0; j < ages.length ; j++) {
                    String q = ages[j]+"月龄"+"("+ (j+1) +"/"+ages.length+")";
                    monthAgeStr+=q;
                    if (ages.length-1 != j)
                    {
                        monthAgeStr+=",";
                    }
                }
                data.setVnMonthAge(monthAgeStr);

                if (data.getVnVaccineType()==1){
                    data.setTypeName(MIAN_FEI);
                    data.setVnVaccineTypeName(YI_LEI_YI_MIAO);
                }else if (data.getVnVaccineType()==2){
                    data.setTypeName(SHOU_FEI);
                    data.setVnVaccineTypeName(ER_LEI_YI_MIAO);
                }

                if (data.getVnPosition().equals(PositionEnum.zero.getId())){
                    data.setVnPositionName(PositionEnum.getTitle(PositionEnum.zero.getId()));
                }else if (data.getVnPosition().equals(PositionEnum.one.getId())) {
                    data.setVnPositionName(PositionEnum.getTitle(PositionEnum.one.getId()));
                } else if (data.getVnPosition().equals(PositionEnum.two.getId())) {
                    data.setVnPositionName(PositionEnum.getTitle(PositionEnum.two.getId()));
                } else if (data.getVnPosition().equals(PositionEnum.three.getId())) {
                    data.setVnPositionName(PositionEnum.getTitle(PositionEnum.three.getId()));
                } else if (data.getVnPosition().equals(PositionEnum.four.getId())) {
                    data.setVnPositionName(PositionEnum.getTitle(PositionEnum.four.getId()));
                } else if (data.getVnPosition().equals(PositionEnum.five.getId())) {
                    data.setVnPositionName(PositionEnum.getTitle(PositionEnum.five.getId()));
                }

            }
            nameAllList.addAll(nameList);
        }

        mv.setViewName("vaccineNameList");
        mv.addObject("vaccineNameList", nameAllList);

        return mv;
    }








}
