package com.lyms.yimiao.web.interceptor;


import com.lymsh.mommybaby.basecommon.base.BaseController;
import com.lymsh.mommybaby.basecommon.base.TokenRequired;
import com.lymsh.mommybaby.basecommon.exception.TokenException;
import com.lymsh.mommybaby.basecommon.util.ContextHolder;
import com.lymsh.mommybaby.basecommon.util.LogUtil;
import com.lymsh.yimiao.main.data.model.YmUsers;
import com.lymsh.yimiao.main.data.service.YmUsersService;
import com.lymsh.yimiao.main.data.util.LoginContext;
import com.lymsh.yimiao.main.data.util.LoginUtil;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.lang.annotation.Annotation;

/**
 * 验证token拦截器
 *
 * <ul>
 *     <li>
 *      1、springmvc中配置TokenValidateInteceptor的拦截
 *      2、在需要拦截的方法上面配置TokenRequired注解
 *     </li>
 * </ul>
 *
 */
public class TokenValidateInteceptor extends HandlerInterceptorAdapter {
    @Autowired
    private YmUsersService usersService;

    public static boolean isSiteController(Object handler) {
        return handler instanceof HandlerMethod && (((HandlerMethod) handler).getBean() instanceof BaseController);
    }

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {

        if (!isSiteController(handler))
            return true;
        TokenRequired clientRequired = findAnnotation((HandlerMethod) handler, TokenRequired.class);
        if (null == clientRequired)
            return true;

        validateToken(request, response);

        return true;
    }

    private <T extends Annotation> T findAnnotation(HandlerMethod handler, Class<T> annotationType) {
        T annotation = handler.getBeanType().getAnnotation(annotationType);
        if (annotation != null)
            return annotation;
        return handler.getMethodAnnotation(annotationType);
    }

    public boolean validateToken(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse) {
        String token = httpServletRequest.getHeader("Authorization");
        if (StringUtils.isEmpty(token)) {
            throw new TokenException();
        }
        LoginContext loginContext = LoginUtil.checkLoginState(token);
        if(!loginContext.isLogin()) {
            throw new TokenException();
        }
        YmUsers users = usersService.getUsersByLoginCenterId(loginContext.getId());
        if(null == users) {
            throw new TokenException();
        }
        loginContext.setId(users.getId());
        loginContext.setToken(token);
        httpServletRequest.setAttribute("loginContext", loginContext);

        LogUtil.tokenInfo(" userId:" + users.getId() + ", ,url:" + httpServletRequest.getRequestURI() + ",method:" + httpServletRequest.getMethod());

        return loginContext.isLogin();
    }
    /**
     * This implementation is empty.
     */
    @Override
    public void afterCompletion(
            HttpServletRequest request, HttpServletResponse response, Object handler, Exception ex)
            throws Exception {
        ContextHolder.clean();
    }
}